# Jasper AI MCP Server

The Jasper AI MCP server enables AI clients to seamlessly integrate with Jasper's powerful content generation and marketing tools. This server opens up new possibilities for developers to build AI-powered applications that leverage Jasper's advanced capabilities.

**What is MCP?**

[MCP](https://modelcontextprotocol.io/) (Model Context Protocol) is an emerging standard that allows AI models to interact with applications through a consistent interface. It acts as an abstraction layer over HTTP, letting AI agents access application functionality without needing to understand specific API protocols.

## Prerequisites

- **Node.js and npm**: Ensure you have Node.js (version >=20.0.0) and npm installed. You can download them from the official [Node.js website](https://nodejs.org/en/download).
- **Jasper AI API Key**: You'll need a Jasper AI API key to authenticate with the service. You can obtain one from your Jasper account settings.

## Installation and Setup

1.  **Install the package**:

    ```bash
    npm install @gojasper/mcp-server
    ```

2.  **Configure your AI client**:

    Add the server configuration to your AI client's configuration file. For example, in Claude Desktop, you would modify `claude_desktop_config.json`:

    ```json
    {
      "mcpServers": {
        "jasper": {
          "command": "npx",
          "args": ["-y", "@gojasper/mcp-server"],
          "env": {
            "JASPER_API_KEY": "<your-jasper-api-key>"
          }
        }
      }
    }
    ```

3.  **Restart your AI client**: After saving the configuration, you may need to restart your AI client to apply the changes. You should now have access to the Jasper tools.

## Available Tools

This MCP server provides a set of tools for interacting with the Jasper AI API.

| Tool Name                 | Description                                                                                                              |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------------ |
| `generate-content`        | Generates content based on a given command, with options for specifying audience, tone, style, and background knowledge. |
| `apply-style`             | Applies a specified style guide's rules to the provided text content, ensuring it conforms to your brand's standards.    |
| `search-knowledge-base`   | Searches your Jasper knowledge base for relevant documents and information.                                              |
| `get-jasper-audiences`    | Retrieves a list of defined audiences from your Jasper account.                                                          |
| `get-jasper-brand-voices` | Retrieves a list of defined brand voices/tones from your Jasper account.                                                 |
| `get-jasper-style-guides` | Retrieves your Jasper style guide ID.                                                                                    |

## Example Usage

Here are some example prompts you can use with an AI client that has the Jasper MCP server configured:

- "Generate a blog post about the benefits of using AI in marketing."
- "Rewrite the following paragraph in a more professional tone: [your paragraph here]"
- "What are the key points from our last marketing meeting? (searches knowledge base)"
- "List all available audiences for our marketing campaigns."
